@@ -1,5 +1,5 @@
 package Git::Database::Backend::Git::Repository;
-$Git::Database::Backend::Git::Repository::VERSION = '0.006';
+$Git::Database::Backend::Git::Repository::VERSION = '0.007';
 use IO::Select;
 use Sub::Quote;
 
@@ -93,6 +93,12 @@ sub get_object_attributes {
     $bang .= $err->getline while $select->can_read(0);
     warn $bang if $bang;
 
+    # git versions >= 2.11.0.rc0 throw more verbose errors
+    if ( $parts[0] =~ /^(?:symlink|dangling|loop|notdir)$/ ) {
+        <$out>;    # eat the next line
+        return undef;
+    }
+
     # object does not exist in the git object database
     return undef if $parts[-1] eq 'missing';
 
@@ -205,7 +211,7 @@ Git::Database::Backend::Git::Repository - A Git::Database backend based on Git::
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -236,7 +242,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2016 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2016-2017 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
