@@ -1,5 +1,5 @@
 package Git::Database::Backend::Git::Sub;
-$Git::Database::Backend::Git::Sub::VERSION = '0.006';
+$Git::Database::Backend::Git::Sub::VERSION = '0.007';
 use Git::Sub qw(
    cat_file
    hash_object
@@ -65,6 +65,9 @@ sub get_object_attributes {
     # protect against weird cases like if $digest contains a space
     my ( $sha1, $kind, $size ) = my @parts = split / /, $meta;
 
+    # git versions >= 2.11.0.rc0 throw more verbose errors
+    return undef if $parts[0] =~ /^(?:symlink|dangling|loop|notdir)$/;
+
     # object does not exist in the git object database
     return undef if $parts[-1] eq 'missing';
 
@@ -163,7 +166,7 @@ Git::Database::Backend::Git::Sub - A Git::Database backend based on Git::Sub
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -194,7 +197,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2016 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2016-2017 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
