@@ -1,5 +1,5 @@
 package Git::Database::Backend::Git::Wrapper;
-$Git::Database::Backend::Git::Wrapper::VERSION = '0.006';
+$Git::Database::Backend::Git::Wrapper::VERSION = '0.007';
 use Cwd qw( cwd );
 use Git::Wrapper;
 use Git::Version::Compare qw( ge_git );
@@ -57,6 +57,9 @@ sub get_object_attributes {
     # protect against weird cases like if $digest contains a space
     my ( $sha1, $kind, $size ) = my @parts = split / /, $meta;
 
+    # git versions >= 2.11.0.rc0 throw more verbose errors
+    return undef if $parts[0] =~ /^(?:symlink|dangling|loop|notdir)$/;
+
     # object does not exist in the git object database
     return undef if $parts[-1] eq 'missing';
 
@@ -138,7 +141,7 @@ Git::Database::Backend::Git::Wrapper - A Git::Database backend based on Git::Wra
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -173,7 +176,7 @@ and L<Git::Database::Role::RefWriter> roles.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2016-2017 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
